<p style="text-align:center;">
<img style="" src="docs_src/logo.png">
</p>

<br>

Bob Telegram Tools is a python library which allows you to monitor your machine learning methods just by using Telegram without any additional application.

Documentation
=============

See https://antonioroberto1994.github.io/bob_telegram_tools/ for detailed instruction, manuals and tutorials.

Installation instructions
=========================

You can install the package with pip:

`pip install bob-telegram-tools` 

License
=======

Code released under the [GNU GENERAL PUBLIC LICENSE](https://github.com/antonioroberto1994/bob_telegram_tools/tree/master/LICENSE).
